@@ -1,5 +1,6 @@
 """Paperless common tests."""
 
+import re
 from dataclasses import dataclass, fields
 from datetime import date, datetime
 from enum import Enum
@@ -21,10 +22,13 @@ from pypaperless.exceptions import (
     PaperlessInactiveOrDeletedError,
     PaperlessInvalidTokenError,
 )
-from pypaperless.models import Page
+from pypaperless.models import CustomField, Page
 from pypaperless.models.base import HelperBase, PaperlessModel
 from pypaperless.models.common import (
+    CUSTOM_FIELD_TYPE_VALUE_MAP,
     CustomFieldDateValue,
+    CustomFieldIntegerValue,
+    CustomFieldMonetaryValue,
     CustomFieldSelectValue,
     CustomFieldType,
     MatchingAlgorithmType,
@@ -44,7 +48,7 @@ from tests.const import (
     PAPERLESS_TEST_USER,
 )
 
-from .data import PATCHWORK
+from .data import DATA_CUSTOM_FIELDS, DATA_PATHS, DATA_TOKEN
 
 # mypy: ignore-errors
 
@@ -55,9 +59,9 @@ class TestPaperless:
     async def test_init(self, resp: aioresponses, api: Paperless) -> None:
         """Test init."""
         resp.get(
-            f"{PAPERLESS_TEST_URL}{API_PATH['api_schema']}",
+            f"{PAPERLESS_TEST_URL}{API_PATH['index']}",
             status=200,
-            payload=PATCHWORK["paths"],
+            payload=DATA_PATHS,
         )
         await api.initialize()
         assert api.is_initialized
@@ -65,15 +69,10 @@ class TestPaperless:
 
     async def test_context(self, resp: aioresponses, api: Paperless) -> None:
         """Test context."""
-        resp.get(
-            f"{PAPERLESS_TEST_URL}{API_PATH['api_schema']}",
-            status=500,
-            payload=PATCHWORK["paths"],
-        )
         resp.get(
             f"{PAPERLESS_TEST_URL}{API_PATH['index']}",
             status=200,
-            payload=PATCHWORK["paths"],
+            payload=DATA_PATHS,
         )
         async with api:
             assert api.is_initialized
@@ -83,20 +82,7 @@ class TestPaperless:
         # version must be None in this case, as we test against
         # an uninitialized Paperless object
         assert api.host_version is None
-
         assert api.base_url == PAPERLESS_TEST_URL
-        assert isinstance(api.local_resources, set)
-        assert isinstance(api.remote_resources, set)
-
-    async def test_helper_avail_00(self, api_00: Paperless) -> None:
-        """Test availability of helpers against specific api version."""
-        assert not api_00.custom_fields.is_available
-        assert not api_00.workflows.is_available
-
-    async def test_helper_avail_latest(self, api_latest: Paperless) -> None:
-        """Test availability of helpers against specific api version."""
-        assert api_latest.custom_fields.is_available
-        assert api_latest.workflows.is_available
 
     async def test_init_error(self, resp: aioresponses, api: Paperless) -> None:
         """Test initialization error."""
@@ -105,11 +91,6 @@ class TestPaperless:
             await api.initialize()
 
         # http status error
-        resp.get(
-            f"{PAPERLESS_TEST_URL}{API_PATH['api_schema']}",
-            status=500,
-            payload=PATCHWORK["paths"],
-        )
         resp.get(
             f"{PAPERLESS_TEST_URL}{API_PATH['index']}",
             status=401,
@@ -119,11 +100,6 @@ class TestPaperless:
             await api.initialize()
 
         # http 401 - inactive or deleted user
-        resp.get(
-            f"{PAPERLESS_TEST_URL}{API_PATH['api_schema']}",
-            status=500,
-            payload=PATCHWORK["paths"],
-        )
         resp.get(
             f"{PAPERLESS_TEST_URL}{API_PATH['index']}",
             status=401,
@@ -133,11 +109,6 @@ class TestPaperless:
             await api.initialize()
 
         # http status forbidden
-        resp.get(
-            f"{PAPERLESS_TEST_URL}{API_PATH['api_schema']}",
-            status=500,
-            payload=PATCHWORK["paths"],
-        )
         resp.get(
             f"{PAPERLESS_TEST_URL}{API_PATH['index']}",
             status=403,
@@ -147,11 +118,6 @@ class TestPaperless:
             await api.initialize()
 
         # http ok, wrong payload
-        resp.get(
-            f"{PAPERLESS_TEST_URL}{API_PATH['api_schema']}",
-            status=500,
-            payload=PATCHWORK["paths"],
-        )
         resp.get(
             f"{PAPERLESS_TEST_URL}{API_PATH['index']}",
             status=200,
@@ -304,7 +270,7 @@ class TestPaperless:
         resp.post(
             f"{PAPERLESS_TEST_URL}{API_PATH['token']}",
             status=200,
-            payload=PATCHWORK["token"],
+            payload=DATA_TOKEN,
         )
         token = await api.generate_api_token(
             PAPERLESS_TEST_URL,
@@ -360,7 +326,7 @@ class TestPaperless:
         resp.post(
             f"{PAPERLESS_TEST_URL}{API_PATH['token']}",
             status=200,
-            payload=PATCHWORK["token"],
+            payload=DATA_TOKEN,
         )
         token = await api.generate_api_token(
             PAPERLESS_TEST_URL,
@@ -384,13 +350,73 @@ class TestPaperless:
         assert WorkflowTriggerType(never_int) == WorkflowTriggerType.UNKNOWN
         assert WorkflowTriggerSourceType(never_int) == WorkflowTriggerSourceType.UNKNOWN
 
-    async def test_custom_field_value_types(self) -> None:
-        """Test custom field value types."""
-        # check date transformation
-        test = CustomFieldDateValue(value="1900-01-02T02:03:04")
-        assert isinstance(test.value, datetime)
+    async def test_custom_field_draft_value_wo_cache(self, paperless: Paperless) -> None:
+        """Test draft custom field value without cache."""
+        custom_field = CustomField.create_with_data(
+            paperless,
+            data={"id": 1337, "name": "Test", "data_type": CustomFieldType.INTEGER},
+            fetched=True,
+        )
+        field_value = custom_field.draft_value(1337)
+        for value_type in CUSTOM_FIELD_TYPE_VALUE_MAP.values():
+            assert not isinstance(field_value, value_type)
 
-        # check label properties
+    async def test_custom_field_draft_value_wslash_cache(
+        self, resp: aioresponses, paperless: Paperless
+    ) -> None:
+        """Test draft custom field value with cache."""
+        # set custom fields cache
+        resp.get(
+            re.compile(r"^" + f"{PAPERLESS_TEST_URL}{API_PATH['custom_fields']}" + r"\?.*$"),
+            status=200,
+            payload=DATA_CUSTOM_FIELDS,
+        )
+        paperless.cache.custom_fields = await paperless.custom_fields.as_dict()
+
+        custom_field = CustomField.create_with_data(
+            api=paperless,
+            data=DATA_CUSTOM_FIELDS["results"][5],
+            fetched=True,
+        )
+        field_value = custom_field.draft_value(1337, expected_type=CustomFieldIntegerValue)
+        assert isinstance(field_value, CustomFieldIntegerValue)
+
+    async def test_custom_field_date_value(self) -> None:
+        """Test `CustomFieldDateValue`."""
+        test = CustomFieldDateValue(value="1900-01-02")
+        assert isinstance(test.value, date)
+        test = CustomFieldDateValue(value="1900-01-02T03:04:05.133337Z")
+        assert isinstance(test.value, date)
+
+    async def test_custom_field_monetary_value(self) -> None:
+        """Test `CustomFieldMonetaryValue`."""
+        field = CustomFieldMonetaryValue(value="EUR1337.00")
+        assert field.currency == "EUR"
+        assert field.amount == 1337
+
+        field.amount = 123.45678
+        assert field.amount == 123.46  # round
+
+        field.extra_data = {"default_currency": "USD"}
+        assert field.value == "EUR123.46"
+
+        field.value = "123.45"  # no currency
+        assert field.currency == "USD"
+
+        field.extra_data = {}
+        assert field.currency == ""
+
+        field.currency = "EUR"
+        assert field.value == "EUR123.45"
+
+        field.currency = ""
+        assert field.value == "123.45"
+
+        field.value = None
+        assert field.amount is None
+
+    async def test_custom_field_select_value(self) -> None:
+        """Test custom field value types."""
         test = CustomFieldSelectValue(
             value="id2",
             extra_data={
